@@ -12,7 +12,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
 
-from .pysisu_class import PySisu  # noqa
-from .version import __version__  # noqa
+from .pysisu_class import PySisu
+from .version import __version__
+
+__all__ = ["PySisu", "__version__"]
